@@ -491,7 +491,8 @@ Read the contents of a single file into a field list.
         word_size = um.get('word_size')
         endian    = um.get('endian')
         umversion = um.get('version')
-        if fmt == 'PP':
+        if fmt in ('PP', 'pp'):
+            fmt = fmt.upper()
             # For PP format, there is a default word size and
             # endian-ness
             if word_size is None:
